@@ -14,7 +14,7 @@ def test_json_variable():
         'set': {1, 2},
         1: uuid_value,
     }
-    container = SqlContainer("SELECT $my_dict->'tuple' as names")(my_dict=my_dict)
+    container = SqlContainer("SELECT $my_dict::json->'tuple' as names")(my_dict=my_dict)
     assert container.dumps() == (
         'SELECT {'
         '"id": 23, '
@@ -22,5 +22,5 @@ def test_json_variable():
         '"tuple": ["a", "b"], '
         '"set": [1, 2], '
         f'"1": "{uuid_value}"'
-        "}->'tuple' as names"
+        "}::json->'tuple' as names"
     )
